==> owncloud-4.5.7.tgz: owncloud/apps/contacts/l10n/lt_LT.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Klaida (de)aktyvuojant adresų knygą.",
"No contacts found." => "Kontaktų nerasta.",
"Information about vCard is incorrect. Please reload the page." => "Informacija apie vCard yra neteisinga. ",
"Error reading contact photo." => "Klaida skaitant kontakto nuotrauką.",
"The loading photo is not valid." => "Netinkama įkeliama nuotrauka.",
"File doesn't exist:" => "Failas neegzistuoja:",
"Error loading image." => "Klaida įkeliant nuotrauką.",
"There is no error, the file uploaded with success" => "Failas įkeltas sėkmingai, be klaidų",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Įkeliamo failo dydis viršija upload_max_filesize nustatymą php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Įkeliamo failo dydis viršija MAX_FILE_SIZE nustatymą, kuris naudojamas HTML formoje.",
"The uploaded file was only partially uploaded" => "Failas buvo įkeltas tik dalinai",
"No file was uploaded" => "Nebuvo įkeltas joks failas",
"Contacts" => "Kontaktai",
"Download" => "Atsisiųsti",
"Edit" => "Keisti",
"Delete" => "Trinti",
"Cancel" => "Atšaukti",
"This is not your addressbook." => "Tai ne jūsų adresų knygelė.",
"Contact could not be found." => "Kontaktas nerastas",
"Work" => "Darbo",
"Home" => "Namų",
"Mobile" => "Mobilusis",
"Text" => "Žinučių",
"Voice" => "Balso",
"Message" => "Žinutė",
"Fax" => "Faksas",
"Video" => "Vaizdo",
"Pager" => "Pranešimų gaviklis",
"Internet" => "Internetas",
"Birthday" => "Gimtadienis",
"Contact" => "Kontaktas",
"Add Contact" => "Pridėti kontaktą",
"Organization" => "Organizacija",
"Nickname" => "Slapyvardis",
"Enter nickname" => "Įveskite slapyvardį",
"Phone" => "Telefonas",
"Email" => "El. paštas",
"Address" => "Adresas",
"Download contact" => "Atsisųsti kontaktą",
"Delete contact" => "Ištrinti kontaktą",
"Type" => "Tipas",
"PO Box" => "Pašto dėžutė",
"City" => "Miestas",
"Region" => "Regionas",
"Zipcode" => "Pašto indeksas",
"Country" => "Šalis",
"Addressbook" => "Adresų knyga",
"Addressbooks" => "Adresų knygos",
"New Address Book" => "Nauja adresų knyga",
"Save" => "Išsaugoti"
);

==> owncloud-5.0.9.tgz: owncloud/apps/contacts/l10n/lt_LT.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Klaida (de)aktyvuojant adresų knygą.",
"No categories selected for deletion." => "Trynimui nepasirinkta jokia kategorija.",
"No contacts found." => "Kontaktų nerasta.",
"Information about vCard is incorrect. Please reload the page." => "Informacija apie vCard yra neteisinga. ",
"Error reading contact photo." => "Klaida skaitant kontakto nuotrauką.",
"The loading photo is not valid." => "Netinkama įkeliama nuotrauka.",
"File doesn't exist:" => "Failas neegzistuoja:",
"Error loading image." => "Klaida įkeliant nuotrauką.",
"There is no error, the file uploaded with success" => "Failas įkeltas sėkmingai, be klaidų",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Įkeliamo failo dydis viršija upload_max_filesize nustatymą php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Įkeliamo failo dydis viršija MAX_FILE_SIZE nustatymą, kuris naudojamas HTML formoje.",
"The uploaded file was only partially uploaded" => "Failas buvo įkeltas tik dalinai",
"No file was uploaded" => "Nebuvo įkeltas joks failas",
"Missing a temporary folder" => "Nėra laikinojo katalogo",
"Contacts" => "Kontaktai",
"Error" => "Klaida",
"Importing..." => "Importuojama...",
"Unable to upload your file as it is a directory or has 0 bytes" => "Neįmanoma įkelti failo - jo dydis gali būti 0 bitų arba tai katalogas",
"Upload Error" => "Įkėlimo klaida",
"Upload too large" => "Įkėlimui failas per didelis",
"Pending" => "Laukiantis",
"Download" => "Atsisiųsti",
"Edit" => "Keisti",
"Delete" => "Trinti",
"Cancel" => "Atšaukti",
"Work" => "Darbo",
"Home" => "Namų",
"Other" => "Kita",
"Mobile" => "Mobilusis",
"Text" => "Žinučių",
"Voice" => "Balso",
"Message" => "Žinutė",
"Fax" => "Faksas",
"Video" => "Vaizdo",
"Pager" => "Pranešimų gaviklis",
"Internet" => "Internetas",
"Contact" => "Kontaktas",
"Settings" => "Nustatymai",
"Import" => "Importuoti",
"OK" => "Gerai",
"Groups" => "Grupės",
"Close" => "Užverti",
"Nickname" => "Slapyvardis",
"Enter nickname" => "Įveskite slapyvardį",
"Title" => "Pavadinimas",
"Organization" => "Organizacija",
"Birthday" => "Gimtadienis",
"Add" => "Pridėti",
"Phone" => "Telefonas",
"Email" => "El. paštas",
"Address" => "Adresas",
"Delete contact" => "Ištrinti kontaktą",
"City" => "Miestas",
"Country" => "Šalis",
"Share" => "Dalintis",
"Export" => "Eksportuoti",
"Addressbooks" => "Adresų knygos",
"New Address Book" => "Nauja adresų knyga",
"Name" => "Pavadinimas",
"Save" => "Išsaugoti"
);
